bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 21. Aventiure
___________________________________________________ #### Auentv wie Chriemhilt von Wormze schiet #### do si gein den Hvnen fvor [50v]
| ### <Die> boten lazen riten vn– tvn iv daz erchant ### wie div kvniginne fvre dvrch daz lant ### der wa von ir cherten ir brvder beide wider ### si heten ir so gedienet daz sis in mvse danchen sider ### Vrlovbes von ir gerte do vil manic degen ### si mvsin sich ze Vergen der reise hine bewegn ### do si wider wolden riten an den Rin ### done mohtez ane weinen von lieben frivnden niht gesin
###### 1318 | ### Giselher der snelle sprach zer swester sin ### swenne daz dv frowe bedurfen wellest min ### ob dir iht gewerre daz tvo mir bechant ### so rite ich dir ze dienste in daz Ezelen lant
###### 1319 | ### Die ir sippe waren die chustes an den munt ### vil minneklichez scheiden chos man an der stvnt ### die snellen Burgonden von Rvdegeres man ### do fvrt div kuniginne manige magt wolgetan
###### 1320 | ### Hundert vn– viere die trugen pfawen chleit ### von genagelten richen pfellen vil der schilde breit ### man fvrte bi den frowen nahen vf den wegn ### do nam ovch vrlovp Volker der vil zierliche degn
| ### Do si vber Tvonowe chomen in Beyerlant ### do wrden disiv mêre witen bechant ### daz zen Hunin fvere Chriemh' div kunigin ### des frevt sich ir Oeheim ein bischof der hiez Pilgerin
###### 1322 | ### In der stat ze Pazzowe was er bisschof ### die herberge wrden lære vn– ovch des fvrsten hof ### si ilten gegen den gesten vf in Bayerlant ### da der bisscof Pilgerin die schonen Chriemh' vant
###### 1323 | ### Sinem ingesinde was daz niht ze leit ### daz si ir volgen sahen so manige schone meit ### da trvote man mit ovgen der <edeln> ritter chint ### vil riche herberge gap man den edeln gesten sint
###### 1324 | ### Da ze Pledelingen schvf man in gemach ### daz volch man allenthalben zvo zin riten sach ### man gab in willechliche des si bedorften da ### si namenz wol mit eren als tet man sider anderswa
###### 1325 | ### Div frowe mit ir oeheim ze Pazzowe reit ### ez was den burgæren darinne niht ze leit ### daz dar chomen solde des fursten swester chint ### si wart vil wol enpfangen von den kovflvten sint
| ### Daz si beliben solden der bisscof hetes wan ### do sprach der marcgrave es enmac niht ergan ### wir mvzin nider riten in der Hvnin lant ### vns wartet vil der degene wande ez in allen ist bechant
###### 1327 | ### Disiv mære ovch wiste div schone Goetelint ### si bereite sich mit vlize gein ir frowen sint ### ir het enboten Rvdeger daz in daz dvhte gvot ### daz si der kuniginne da mite troste den mvot
###### 1328 | ### daz si ir rite engegene mit den sinen man ### vf zvo der Ense do daz wart getan ### do sah man allenthalben vil vnmvoze pflegn [51r] ### durch der geste liebe si mvsin rowe sich bewegn
###### 1329 | ### Si was der næhsten nahte ze Everdingen chomen ### gnvoge vz Bayerlande solden si han genomen ### den rovp vf der straze nach ir gewonheit ### so heten si den gesten erboten eteslichiv leit
###### 1330 | ### Daz hete wol behvetet der edel Rvedeger ### er fvorte tvsint ritter vn– dannoch mer ### do was oech chomen Gotelint des marcgraven wip ### mit ir fvor herrenliche vil maniges chvnen rechen lip
| ### Do si vber die Trvone chomen bi Ense vf daz velt ### do sah man vf gespannen hvetten vn– gezelt ### da die geste solden die nahtselde han ### von Rvdegeres frivnden wart in dienste vil getan
###### 1332 | ### Gotelint div schoene die herberge lie ### hinder ir beliben vf den wegn gie ### mit chlingenden zoemen die moere wolgetan ### der antfanch wart vil schoene liep was iz Rvdegere ir man
###### 1333 | ### Di in ze beden siten chomen vf den wegen ### die riten vroliche der was vil manic degen ### si pflagen ritterschefte daz sach vil manic meit ### ovch was der helede dienest den schonen frowen niht ze leit
###### 1334 | ### Do zvo den gesten chomen die Rvdegeres man ### vil der trvonzvne sach man ze berge gan ### von den rechen handen mit ritterlichen siten ### da wart wol ze prise vor den frowen geriten
| ### Daz liezen si beliben do grvzte manic man ### vil gvtlich ein ander do fvrten si von dan ### die schonen Gotelinde da si Chriemh' sach ### die frowen dienen chunden die musin liden vngemach
###### 1336 | ### Der voget von Bechelaren zv sime wibe reit ### der edelen marcgrauinne was daz niht ze leit ### daz er so wol gesunder was von Rine chomen ### ia was ir vil ir sorgen mit grozen vrevden benomen
###### 1337 | ### Do si in het enpfangen er <si> hiez vf daz gras ### erbeizen mit den frowen swaz ir da mit ir was ### mit dienste was vnmvzich da vil manic man ### der wart den schonen frowen mit grozem vlize getan
###### 1338 | ### Do sach div kuniginne hie Gotelinde sten ### mit ir ingesinde si lie niht naher gen ### daz pferit mit dem zovme zvchen si began ### si bat sich heben balde nider von dem satel dan
###### 1339 | ### Den bisscof sach man wisen siner swester chint ### in vn– Ekkewarten zvo Gotelinde sint ### da wart vil michel wichen an der selben stvnt ### do chuste div ellende an der marcgrauinne munt
| ### Do sprach vil minnekliche daz Rvdegeres wip ### nv wol mich liebiv frowe deich iwern schonen lip ### han in disen landen mit frevden hie gesehn ### mir enchvnde in disen citen nimmer lieber geschehen
###### 1341 | ### Nv lon iv got sprach Chriemh' vil edel Gotelint ### sol ich gesvnt beliben vn– Botelunges chint ### ez mag [51v]iv chomen ze liebe daz ir mich habt gesehn ### in beiden was unchvnde daz sider mvose geschehn
###### 1342 | ### Mit zvhten zv zein ander si sazen vf den chlê ### die gerne frowen sahen den was da niht ze we ### ir sveziv ovgenweide braht in hohen mvot ### den wiben sam den mannen als ez noch vil dicke tvot
###### 1343 | ### Man hiez den gesten schenchen ez was wol mitter tac ### daz edel ingesinde da niht langer lac ### si riten da si fvnden vil manige hvtten breit ### da was den werden gesten vil groziv wirtschaft bereit
| ### Die naht si heten rowe vnz an den morgen frvo ### die von Bechelaren bereiten sich dar zvo ### wie si behalten solden vil manigen werden gast ### wol het geschaffen Rvdeger daz in vil wenich iht gebrast
###### 1345 | ### Div venster an den mvoren sah man offen stan ### div guote Bechelaren div was vf getan ### dar ine riten geste die man vil gerne sach ### den het der wirt vil edele schaffen richen gemach
###### 1346 | ### Div Rvdegeres tohter mit ir gesinde gie ### da si die kvniginne vil minneklich enpfie ### da bi was ovch ir mvoter des marcgraven wip ### mit liebe wart gegrvezet vil maniger ivncfrowen lip
###### 1347 | ### Si viengen sich bi henden vn– giengen dan ### in einen palas witen der was vil wolgetan ### da div Tvonowe vnden hine vloz ### si sazen gegen dem lvofte vn– heten churcewile groz
| ### Wes si nv mere pflêgen des enchan niht gesagn ### daz in so vbele zogete daz horte man do chlagen ### die Chriemh' rechen wandez was in leit ### hey waz gvter degene mit ir von Bechelaren reit
###### 1349 | ### Vil minneklichen dienest der marcgrave in bot ### do gabt div kuniginne zwelf povge rot ### der Gotlinde tohter vn– also gvot gewant ### daz si niht bezzers brahte in daz Etzelen lant
###### 1350 | ### Swie ir genomen wære der Nibelunge golt ### alle die si gesahen die machte si ir holt ### noch mit dem chleinem gvote daz si da mohte han ### des wirtes ingesinde wart michel gabe getan
###### 1351 | ### Da widere bot do ere div frowe Gotelint ### den gesten von dem Rine so minnekliche sint ### daz man do der fremden harte wenich vant ### sine trvgen ir gesteine oder ir vil herlich gewant
| ### Do si enbizzen waren vn– daz si solden dan ### von der hvosfrowen wart geboten an ### getriwelicher dienest daz Etzelen wip ### do wart ovch vil getrvtet der schonen iuncfrowen lip
###### 1353 | ### Si sprach zer kuniginne swenne ivch nv dunchet gvot ### ich weiz wol daz iz gerne min lieber vater tvot ### daz er mich zvo ziv sendet in der Hvnin [52r]lant ### daz si ir getriwe wære vil wol daz Chriemh' ervant
###### 1354 | ### Div ros bereitet waren fvr Bechelaren chomen ### ovch het div kuniginne vrlovp nv genomen ### von Rvdegeres wibe vn– von der tohter sin ### do schiet ovch sich mit grveze vil manic schone magedin
###### 1355 | ### Ein ander si vil selten gesahen nach den tagen ### vzer Medeliche vf handen wart getragen ### manic goltvaz riche dar inne braht man win ### den gesten vf die straze vn– bat si willechomen sin
###### 1356 | ### Ein wirt < > da gesezzen Astolt was der nant ### der wiste si die straze nider in Osterlande ### gegen Mvtaren die Tnowe nider ### da wart vil wol gedienet der richen kuniginne sider
| ### Der bisschof minnekliche von siner nifteln schiet ### daz si den kunic beeherte wie vast er ir daz riet ### vn– daz si ir ere chovfte sam Helche het getan ### hey waz si grozer eren sit da zen Hvnin gewan
###### 1358 | ### Zvo der Treysem brahte man die geste dan ### ir pflagen vlizzekliche die Rvdegeres man ### vnze daz die Huninn riten vber lant ### do wart der chuniginne vil michel ere bechant
###### 1359 | ### Bi der Treysem hete der kunic von Hunin lant ### eine burch vil riche div was wol bechant ### geheizen Treysenmvore frov Helche saz da ê ### vn– pflach so grozer tugende deiz wetlich nimmer mer erge
###### 1360 | ### ezen tæte danne Chriemh' div also chvnde gebn ### si mohte nach ir leide daz liep vil wol gelebn ### daz ir iahen ere die Etzelen man ### der si sit grozen vollen bi den helden gewan
| ### Div Etzelen herschaft was so wit erchant ### daz nnan zallen citen in sime hofe vant ### die aller besten rechen von den ie wart vernomen ### vnder kristen un– vnder heiden die waren gein der brvte chomen
###### 1362 | ### Bi im was zallen citen daz wætlich mer erge ### kristenlicher orden vn– ovch der heiden ê ### in swie getanem lebene sich ieslicher trvoc ### daz schvof des kuniges milte daz man allen gap genvoch

<<< Übersicht <<< vorige Seite nächste Seite >>>